@@ -16,13 +16,14 @@ from jsonbourne.core import (
 )
 from jsonbourne.jsonlib import import_json
 
-sys.modules['JSON'].__class__ = JSONModuleCls
+sys.modules["JSON"].__class__ = JSONModuleCls
 stringify = JSON.stringify
 dumps = JSON.dumps
 binify = JSON.binify
 dumpb = JSON.dumpb
 loads = JSON.loads
 parse = JSON.parse
+jsoncp = JSON.jsoncp
 json_lib = JSON.json_lib
 which = JSON.which
 use_orjson = JSON.use_orjson
@@ -32,31 +33,29 @@ jsonify = JSON.jsonify
 unjsonify = JSON.unjsonify
 JSONDecodeError = JSON.JSONDecodeError
 
-__all__ = [
-    '__version__',
-    'json',  # json compat lib
-    # core
-    'JsonObjMutableMapping',
-    'JsonObj',
-    'JsonDict',
-    'JSONModuleCls',
-    # import
-    'import_json',
-    'use_orjson',
-    'use_rapidjson',
-    'use_json_stdlib',
-    # util funks
-    'stringify',
-    'binify',
-    'dumps',
-    'dumpb',
-    'loads',
-    'json_lib',
-    'jsonify',
-    'unjsonify',
-    'parse',
-    'undefined',
-    'UNDEFINED',
-    'Null',
-    'null',
-]
+__all__ = (
+    "JSONModuleCls",
+    "JsonDict",
+    "JsonObj",
+    "JsonObjMutableMapping",
+    "Null",
+    "UNDEFINED",
+    "__version__",
+    "binify",
+    "dumpb",
+    "dumps",
+    "import_json",
+    "json",
+    "json_lib",
+    "jsoncp",
+    "jsonify",
+    "loads",
+    "null",
+    "parse",
+    "stringify",
+    "undefined",
+    "unjsonify",
+    "use_json_stdlib",
+    "use_orjson",
+    "use_rapidjson",
+)
