@@ -3,12 +3,13 @@
 
 from functools import lru_cache
 from pprint import pformat
-from typing import Any, Dict, Set, Type, TypeVar
+from typing import Any, Callable, Dict, Optional, Set, Type, TypeVar
 
 from pydantic import (
     VERSION as __pydantic_version__,
     BaseConfig,
     BaseModel,
+    BaseSettings,
     Extra,
     Field,
     ValidationError,
@@ -17,18 +18,20 @@ from pydantic.generics import GenericModel
 
 from jsonbourne.core import JSON, JsonObj
 
-JsonBaseModelT = TypeVar('JsonBaseModelT', bound='JsonBaseModel')
+JsonBaseModelT = TypeVar("JsonBaseModelT", bound="JsonBaseModel")
 
 __all__ = (
-    '__pydantic_version__',
-    'JsonBaseModelDefaultConfig',
-    'JsonBaseModel',
-    'JsonBaseModelT',
-    'BaseModel',
-    'Field',
-    'ValidationError',
-    'JsonGenericModel',
-    'GenericModel',
+    "__pydantic_version__",
+    "JsonBaseModelDefaultConfig",
+    "JsonBaseModel",
+    "JsonBaseModelT",
+    "JsonBaseSettings",
+    "BaseModel",
+    "BaseSettings",
+    "Field",
+    "ValidationError",
+    "JsonGenericModel",
+    "GenericModel",
 )
 
 
@@ -53,28 +56,34 @@ class JsonBaseModel(BaseModel, JsonObj):  # type: ignore
 
     def __init__(self, *args: Any, **kwargs: Any):  # type: ignore
         """Construct a JsonBaseModel and allow for `__post_init__` functions"""
-        super().__init__(*args, **kwargs)
+        if self.__custom_root_type__ and len(args) == 1 and "__root__" not in kwargs:
+            super().__init__(**{**kwargs, "__root__": args[0]})
+        else:
+            super().__init__(*args, **kwargs)
         self.__post_init__()
 
     def __post_init__(self) -> Any:
         """Function place holder that is called after object initialization"""
         pass  # pylint: disable=unnecessary-pass
 
+    def __json_interface__(self) -> Dict[str, Any]:
+        return self.dict()
+
     def to_str(
         self, minify: bool = False, width: int = 120, fmt_kwargs: bool = False
     ) -> str:
         if fmt_kwargs:
-            return type(self).__name__ + '(' + self.__repr_str__(', ') + ')'
+            return type(self).__name__ + "(" + self.__repr_str__(", ") + ")"
         if minify:
-            return type(self).__name__ + '(**' + str(self.to_dict_filter_none()) + ')'
-        return ''.join(
+            return type(self).__name__ + "(**" + str(self.to_dict_filter_none()) + ")"
+        return "".join(
             [
                 type(self).__name__,
-                '(**{\n     ',
+                "(**{\n     ",
                 pformat(self.to_dict_filter_none(), width=width)[1:-1].replace(
-                    '\n', '\n    '
+                    "\n", "\n    "
                 ),
-                '\n})',
+                "\n})",
             ]
         )
 
@@ -86,7 +95,7 @@ class JsonBaseModel(BaseModel, JsonObj):  # type: ignore
 
     def _repr_html_(self) -> str:
         """Return the HTML representation of the object"""
-        return '<pre>{}</pre>'.format(self.__str__())
+        return "<pre>{}</pre>".format(self.__str__())
 
     def to_dict_filter_none(self) -> Dict[str, Any]:
         """Eject object and filter key-values equal to (sub)class' default
@@ -189,6 +198,25 @@ class JsonBaseModel(BaseModel, JsonObj):  # type: ignore
         """Eject and return object as plain jane dictionary"""
         return self.eject()
 
+    def JSON(
+        self,
+        fmt: bool = False,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> str:
+        return JSON.dumps(
+            self.dict(),
+            fmt=fmt,
+            pretty=pretty,
+            sort_keys=sort_keys,
+            append_newline=append_newline,
+            default=default,
+            **kwargs,
+        )
+
     @classmethod
     def from_dict_filtered(
         cls: Type[JsonBaseModelT], dictionary: Dict[str, Any]
@@ -308,6 +336,12 @@ class JsonBaseModel(BaseModel, JsonObj):  # type: ignore
         return self.__class__._cls_field_names()
 
 
+class JsonBaseSettings(BaseSettings, JsonBaseModel):  # type: ignore
+    """pydantic BaseSettings + JsonBaseModel"""
+
+    ...
+
+
 class JsonGenericModel(GenericModel, JsonBaseModel):  # type: ignore
     """Hybrid `pydantic.generics.GenericModel` and `jsonbourne.JsonObj`"""
 
